Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
ghost/__init__.py | (no class) | 5 | 0 | 0 | 100%
ghost/abs_resources.py | GhostResource | 81 | 14 | 0 | 83%
ghost/abs_resources.py | GhostAdminResource | 46 | 16 | 0 | 65%
ghost/abs_resources.py | GhostContentResource | 0 | 0 | 0 | 100%
ghost/abs_resources.py | (no class) | 51 | 0 | 0 | 100%
ghost/client.py | GhostClient | 71 | 16 | 0 | 77%
ghost/client.py | GhostContent | 11 | 4 | 0 | 64%
ghost/client.py | GhostContent.resource._Resource | 0 | 0 | 0 | 100%
ghost/client.py | GhostAdmin | 17 | 4 | 0 | 76%
ghost/client.py | GhostAdmin.resource._Resource | 0 | 0 | 0 | 100%
ghost/client.py | (no class) | 53 | 0 | 0 | 100%
ghost/exceptions.py | BaseGhostException | 6 | 1 | 0 | 83%
ghost/exceptions.py | GhostResponseException | 0 | 0 | 0 | 100%
ghost/exceptions.py | GhostUnknownException | 0 | 0 | 0 | 100%
ghost/exceptions.py | GhostJSONException | 0 | 0 | 0 | 100%
ghost/exceptions.py | GhostResourceNotFoundException | 0 | 0 | 0 | 100%
ghost/exceptions.py | GhostWrongApiError | 0 | 0 | 0 | 100%
ghost/exceptions.py | (no class) | 10 | 0 | 0 | 100%
ghost/resources.py | PostResource | 0 | 0 | 0 | 100%
ghost/resources.py | PageResource | 0 | 0 | 0 | 100%
ghost/resources.py | TagResource | 0 | 0 | 0 | 100%
ghost/resources.py | MemberResource | 0 | 0 | 0 | 100%
ghost/resources.py | UserResource | 0 | 0 | 0 | 100%
ghost/resources.py | AuthorResource | 0 | 0 | 0 | 100%
ghost/resources.py | SettingsResource | 0 | 0 | 0 | 100%
ghost/resources.py | SiteResource | 1 | 0 | 0 | 100%
ghost/resources.py | ImageResource | 10 | 0 | 0 | 100%
ghost/resources.py | ThemeResource | 15 | 15 | 0 | 0%
ghost/resources.py | (no class) | 36 | 0 | 0 | 100%
ghost/results.py | GhostResult | 17 | 3 | 0 | 82%
ghost/results.py | GhostResultSet | 25 | 3 | 0 | 88%
ghost/results.py | (no class) | 27 | 0 | 0 | 100%
setup.py | (no class) | 10 | 10 | 0 | 0%
test_ghost.py | (no class) | 38 | 0 | 0 | 100%
Total |  | 530 | 86 | 0 | 84%

No items found using the specified filter.